-- BEGIN COPYRIGHT
-- *************************************************************************
-- 
--  Licensed Materials - Property of IBM
--  5725-C94, 5725-C95, 5725-C96
--  (C) Copyright IBM Corporation 2013. All Rights Reserved.
--  US Government Users Restricted Rights- Use, duplication or disclosure
--  restricted by GSA ADP Schedule Contract with IBM Corp.
-- 
-- *************************************************************************
-- END COPYRIGHT

-- *******************************************
-- AppScheduler
-- *******************************************

CREATE TABLE @SCHEMA@.WSCH_TASK
(
  TASKID             NUMBER(19)            NOT NULL ,
  VERSION            VARCHAR2(5)           NOT NULL ,
  ROW_VERSION        NUMBER(10)            NOT NULL ,
  TASKTYPE           NUMBER(10)            NOT NULL ,
  TASKSUSPENDED      NUMBER(1)             NOT NULL ,
  CANCELLED          NUMBER(1)             NOT NULL ,
  NEXTFIRETIME       NUMBER(19)            NOT NULL ,
  STARTBYINTERVAL    VARCHAR2(254)                  ,
  STARTBYTIME        NUMBER(19)                     ,
  VALIDFROMTIME      NUMBER(19)                     ,
  VALIDTOTIME        NUMBER(19)                     ,
  REPEATINTERVAL     VARCHAR2(254)                  ,
  MAXREPEATS         NUMBER(10)            NOT NULL ,
  REPEATSLEFT        NUMBER(10)            NOT NULL ,
  TASKINFO           BLOB                           ,
  NAME               VARCHAR2(254)                  ,
  AUTOPURGE          NUMBER(10)            NOT NULL ,
  FAILUREACTION      NUMBER(10)                     ,
  MAXATTEMPTS        NUMBER(10)                     ,
  QOS                NUMBER(10)                     ,
  PARTITIONID        NUMBER(10)                     ,
  OWNERTOKEN         VARCHAR2(200)         NOT NULL ,
  CREATETIME         NUMBER(19)            NOT NULL ,
  PRIMARY KEY (TASKID)
) ;

CREATE INDEX @SCHEMA@.WSCH_TASK_IDX1 ON @SCHEMA@.WSCH_TASK
(
  TASKID, OWNERTOKEN
) ;

CREATE INDEX @SCHEMA@.WSCH_TASK_IDX2 ON @SCHEMA@.WSCH_TASK
(
  NEXTFIRETIME ASC ,
  REPEATSLEFT ,
  PARTITIONID
) ;

CREATE TABLE @SCHEMA@.WSCH_TREG
(
  REGKEY             VARCHAR2(254)         NOT NULL ,
  REGVALUE           VARCHAR2(254)                  ,
  PRIMARY KEY ( REGKEY )
) ;

CREATE TABLE @SCHEMA@.WSCH_LMGR
(
  LEASENAME          VARCHAR2(254)         NOT NULL ,
  LEASEOWNER         VARCHAR2(254)                  ,
  LEASE_EXPIRE_TIME  NUMBER(19)                     ,
  DISABLED           VARCHAR2(254)                  ,
  PRIMARY KEY ( LEASENAME )
) ;

CREATE TABLE @SCHEMA@.WSCH_LMPR
(
  LEASENAME          VARCHAR2(254)         NOT NULL ,
  NAME               VARCHAR2(254)         NOT NULL ,
  VALUE              VARCHAR2(254)         NOT NULL
) ;

CREATE INDEX @SCHEMA@.WSCH_LMPR_IDX1 ON @SCHEMA@.WSCH_LMPR
(
  LEASENAME, NAME
) ;

-- *******************************************
-- Customization
-- *******************************************
-- *******************************************
-- Create the BYTESTORE table
-- *******************************************

CREATE TABLE @SCHEMA@.BYTESTORE
  (ARTIFACTTNS VARCHAR2(250) NOT NULL,
   ARTIFACTNAME VARCHAR2(200) NOT NULL,
   ARTIFACTTYPE VARCHAR2(50) NOT NULL,
   INITIALBYTES BLOB,
   TIMESTAMP1 NUMBER(19) NOT NULL,
   FILENAME VARCHAR2(250),
   BACKINGCLASS VARCHAR2(250),
   CHARENCODING VARCHAR2(50),
   APPNAME VARCHAR2(200),
   COMPONENTTNS VARCHAR2(250),
   COMPONENTNAME VARCHAR2(200),
   SCAMODULENAME VARCHAR2(200),
   SCACOMPONENTNAME VARCHAR2(200));

ALTER TABLE @SCHEMA@.BYTESTORE
  ADD CONSTRAINT PK_BYTESTORE PRIMARY KEY (ARTIFACTTYPE, ARTIFACTTNS, ARTIFACTNAME);

CREATE INDEX @SCHEMA@.BYTESTORE_INDEX1 ON @SCHEMA@.BYTESTORE (
      COMPONENTTNS,
      COMPONENTNAME);

CREATE INDEX @SCHEMA@.BYTESTORE_INDEX2 ON @SCHEMA@.BYTESTORE (
      ARTIFACTTYPE,
      COMPONENTTNS,
      COMPONENTNAME);


-- *******************************************
-- Create the BYTESTOREOVERFLOW table
-- *******************************************

CREATE TABLE @SCHEMA@.BYTESTOREOVERFLOW
  (ARTIFACTTYPE VARCHAR2(50) NOT NULL,
   ARTIFACTTNS VARCHAR2(250) NOT NULL,
   ARTIFACTNAME VARCHAR2(200) NOT NULL,
   SEQUENCENUMBER NUMBER(10) NOT NULL,
   BYTES BLOB);

ALTER TABLE @SCHEMA@.BYTESTOREOVERFLOW
  ADD CONSTRAINT PK_BYTESTOREOVERFL PRIMARY KEY (ARTIFACTTYPE, ARTIFACTTNS, ARTIFACTNAME, SEQUENCENUMBER);


-- *******************************************
-- Create the APPTIMESTAMP table
-- *******************************************

CREATE TABLE @SCHEMA@.APPTIMESTAMP
  (APPNAME VARCHAR2(200) NOT NULL,
   TIMESTAMP1 NUMBER(19) NOT NULL);

ALTER TABLE @SCHEMA@.APPTIMESTAMP
  ADD CONSTRAINT PK_APPTIMESTAMP PRIMARY KEY (APPNAME);

-- *******************************************
-- Create the CUSTPROPERTIES table
-- *******************************************

CREATE TABLE @SCHEMA@.CUSTPROPERTIES
  (PROPERTYID VARCHAR (128) NOT NULL,
   ARTIFACTTNS VARCHAR(250) NOT NULL,
   ARTIFACTNAME VARCHAR(200) NOT NULL,
   ARTIFACTTYPE VARCHAR(50) NOT NULL,
   PNAME VARCHAR(250) NOT NULL,
   PVALUE VARCHAR(250) NOT NULL,
   PTYPE VARCHAR (16) NOT NULL);

ALTER TABLE @SCHEMA@.CUSTPROPERTIES
  ADD CONSTRAINT PK_CUSTPROPERTIES PRIMARY KEY (PROPERTYID);

CREATE INDEX @SCHEMA@.CUSTPROPERTIES_INDEX1 ON @SCHEMA@.CUSTPROPERTIES (
      ARTIFACTTYPE,
      ARTIFACTTNS);  
      
CREATE INDEX @SCHEMA@.CUSTPROPERTIES_INDEX2 ON @SCHEMA@.CUSTPROPERTIES (
      ARTIFACTTYPE,
      ARTIFACTNAME);
  
CREATE INDEX @SCHEMA@.CUSTPROPERTIES_INDEX3 ON @SCHEMA@.CUSTPROPERTIES (
      ARTIFACTTYPE,
      ARTIFACTTNS,
      ARTIFACTNAME);  
      
CREATE INDEX @SCHEMA@.CUSTPROPERTIES_INDEX4 ON @SCHEMA@.CUSTPROPERTIES (
      ARTIFACTTYPE,
      PNAME);      
      
CREATE INDEX @SCHEMA@.CUSTPROPERTIES_INDEX5 ON @SCHEMA@.CUSTPROPERTIES (
      ARTIFACTTYPE,
      ARTIFACTTNS,
      PNAME);      


-- *******************************************
-- DirectDeploy
-- *******************************************

create TABLE @SCHEMA@.d2d_item (
    id varchar(255) not null, 
    state varchar(20) not null,
    item_level int not null,
    module_name varchar(255),
    application_name varchar(255),
    version varchar(30), 
    wps_version varchar(10),
    new_app_name varchar(255),
    primary key (id));

create TABLE @SCHEMA@.d2d_progress (
    item_id varchar(255) not null,
    progress INTEGER,
    progress_msg varchar(255),
    progress_error_code  varchar(255),
    primary key (item_id));

create TABLE @SCHEMA@.d2d_content (
    item_id varchar(255) not null,
    pi  blob,
    primary key (item_id));

create TABLE @SCHEMA@.d2d_metadata(
    item_id varchar(255) not null,
    name varchar(255) not null,
    value varchar(255) );

create TABLE @SCHEMA@.d2d_lock(
    item_lock character(1),
    lastUpdate timestamp);

insert into @SCHEMA@.d2d_lock values ('x', null);

create TABLE @SCHEMA@.d2d_message(
    item_id varchar(255) not null,
    seq int not null,
    id  varchar(63),
    description varchar(1024),
    affected_resource varchar(255),
    location varchar(63),
    folder varchar(255),
    chr varchar(63),
    tag varchar(63),
    severity varchar(15),
    time timestamp,
    primary key (item_id, seq));


-- *******************************************
-- ESDLoggerMediation
-- *******************************************

CREATE TABLE @SCHEMA@.MsgLog
  (TimeStamp TIMESTAMP(6) NOT NULL,
   MessageID VARCHAR2(36) NOT NULL,
   MediationName VARCHAR2(256) NOT NULL,
   ModuleName VARCHAR2(256),
   Message CLOB,
   Version VARCHAR2(10));

ALTER TABLE @SCHEMA@.MsgLog
  ADD CONSTRAINT PK_MSGLOG PRIMARY KEY (TimeStamp, MessageID, MediationName);


-- *******************************************
-- GovernanceRepository
-- *******************************************

  CREATE TABLE @SCHEMA@.W_LIT_DOUBLE 
   (    ID NUMBER(*,0), 
    LITVAL FLOAT(126)
   ) ;
  ALTER TABLE @SCHEMA@.W_LIT_DOUBLE ADD PRIMARY KEY (ID) ENABLE;

  CREATE INDEX @SCHEMA@.idx_obj_dbl ON @SCHEMA@.w_lit_double (litval);
 
  CREATE TABLE @SCHEMA@.W_LIT_FLOAT 
   (    ID NUMBER(*,0), 
    LITVAL FLOAT(63)
   ) ;
  ALTER TABLE @SCHEMA@.W_LIT_FLOAT ADD PRIMARY KEY (ID) ENABLE;

  CREATE INDEX @SCHEMA@.idx_obj_flt ON @SCHEMA@.w_lit_float (litval);
 
  CREATE TABLE @SCHEMA@.W_LIT_LONG 
   (    ID NUMBER(*,0), 
    LITVAL NUMBER(38,0)
   ) ;
  ALTER TABLE @SCHEMA@.W_LIT_LONG ADD PRIMARY KEY (ID) ENABLE;

  CREATE INDEX @SCHEMA@.idx_obj_long ON @SCHEMA@.w_lit_long (litval);
 
  CREATE TABLE @SCHEMA@.W_NAMESPACE 
   (    ID NUMBER(*,0), 
    NAMESPACE VARCHAR2(254) NOT NULL ENABLE
   ) ;
  ALTER TABLE @SCHEMA@.W_NAMESPACE ADD PRIMARY KEY (ID) ENABLE;
 
  CREATE TABLE @SCHEMA@.W_OBJ_LIT_ANY 
   (    ID NUMBER(*,0), 
    LARGE BLOB, 
    HASH VARCHAR2(40), 
    TYPE_URI VARCHAR2(254) NOT NULL ENABLE
   ) ;
  ALTER TABLE @SCHEMA@.W_OBJ_LIT_ANY ADD PRIMARY KEY (ID) ENABLE;

  CREATE INDEX @SCHEMA@.idx_obj_any ON @SCHEMA@.w_obj_lit_any (type_uri);
 
  CREATE TABLE @SCHEMA@.W_OBJ_LIT_DATE 
   (    ID NUMBER(*,0), 
    LITVAL TIMESTAMP (6)
   ) ;
  ALTER TABLE @SCHEMA@.W_OBJ_LIT_DATE ADD PRIMARY KEY (ID) ENABLE;
 
  CREATE INDEX @SCHEMA@.idx_obj_date ON @SCHEMA@.w_obj_lit_date (litval);

  CREATE TABLE @SCHEMA@.W_OBJ_LIT_DATETIME 
   (    ID NUMBER(*,0), 
    LITVAL TIMESTAMP (6)
   ) ;
  ALTER TABLE @SCHEMA@.W_OBJ_LIT_DATETIME ADD PRIMARY KEY (ID) ENABLE;

  CREATE INDEX @SCHEMA@.idx_obj_time ON @SCHEMA@.w_obj_lit_datetime (litval);

 
  CREATE TABLE @SCHEMA@.W_OBJ_LIT_STRING 
   (    ID NUMBER(*,0), 
    LARGE BLOB, 
    LITVAL VARCHAR2(1024), 
    HASH VARCHAR2(40)
   ) ;
  ALTER TABLE @SCHEMA@.W_OBJ_LIT_STRING ADD PRIMARY KEY (ID) ENABLE;

  CREATE INDEX @SCHEMA@.idx_obj_str ON @SCHEMA@.w_obj_lit_string (hash);
 
  CREATE TABLE @SCHEMA@.W_STATEMENT 
   (    ID NUMBER(*,0), 
    VERSION_FROM NUMBER(*,0) NOT NULL ENABLE, 
    VERSION_TO NUMBER(*,0) NOT NULL ENABLE, 
    SUBJ_ID NUMBER(*,0) NOT NULL ENABLE, 
    PRED_ID NUMBER(*,0) NOT NULL ENABLE, 
    OBJ_ID NUMBER(*,0) NOT NULL ENABLE, 
    OBJ_TYP_CD NUMBER(*,0) NOT NULL ENABLE,
    PARTITION_ID NUMBER(*,0) NOT NULL ENABLE
   ) ;
  ALTER TABLE @SCHEMA@.W_STATEMENT ADD PRIMARY KEY (ID) ENABLE;
  
  CREATE INDEX @SCHEMA@.idx_smt_by_sbj ON @SCHEMA@.w_statement (subj_id, version_from, version_to);
  CREATE INDEX @SCHEMA@.idx_smt_by_fvr ON @SCHEMA@.w_statement (version_from);
  CREATE INDEX @SCHEMA@.idx_sbj_by_prp ON @SCHEMA@.w_statement (pred_id, obj_id);
  CREATE INDEX @SCHEMA@.idx_smt_by_val ON @SCHEMA@.w_statement (obj_id, subj_id);
  CREATE INDEX @SCHEMA@.idx_val_by_prp ON @SCHEMA@.w_statement (subj_id, pred_id);
 
  CREATE TABLE @SCHEMA@.W_URI 
   (    ID NUMBER(*,0), 
    URI VARCHAR2(254) NOT NULL ENABLE, 
    NAMESPACE_ID NUMBER(*,0) NOT NULL ENABLE
   ) ;
  ALTER TABLE @SCHEMA@.W_URI ADD PRIMARY KEY (ID) ENABLE;
  ALTER TABLE @SCHEMA@.W_URI ADD CONSTRAINT W_URI_FK_NAMESP FOREIGN KEY (NAMESPACE_ID)
      REFERENCES @SCHEMA@.W_NAMESPACE (ID) ENABLE;
 
  CREATE TABLE @SCHEMA@.W_VERSION 
   (    USERNAME VARCHAR2(64) NOT NULL ENABLE, 
    CHANGE_TIME TIMESTAMP (6) NOT NULL ENABLE, 
    CL_GID VARCHAR2(36), 
    CL_LID VARCHAR2(10), 
    SCHEMA_NS_ID NUMBER(*,0), 
    SCHEMA_REV NUMBER(*,0), 
    ID NUMBER(*,0) NOT NULL ENABLE,
    PARTITION_ID NUMBER(*,0) NOT NULL ENABLE
   ) ;
  ALTER TABLE @SCHEMA@.W_VERSION ADD PRIMARY KEY (ID, PARTITION_ID) ENABLE;
  ALTER TABLE @SCHEMA@.W_VERSION ADD CONSTRAINT W_VER_FK_NAMESP FOREIGN KEY (SCHEMA_NS_ID)
      REFERENCES @SCHEMA@.W_NAMESPACE (ID) ENABLE;

  CREATE INDEX @SCHEMA@.idx_ver_schema ON @SCHEMA@.w_version (schema_ns_id);

CREATE TABLE @SCHEMA@.W_ARTIFACT_BLOB 
(
 ID VARCHAR2(254) NOT NULL, 
 CONTENT BLOB, 
 DELETED NUMBER(1,0)
);
ALTER TABLE @SCHEMA@.W_ARTIFACT_BLOB ADD PRIMARY KEY (ID) ENABLE;

CREATE UNIQUE INDEX @SCHEMA@.IDX_URI ON @SCHEMA@.W_URI (URI);
CREATE UNIQUE INDEX @SCHEMA@.IDX_URI_BY_NS ON @SCHEMA@.W_URI (NAMESPACE_ID, ID);

CREATE UNIQUE INDEX @SCHEMA@.IDX_NAMESPACE ON @SCHEMA@.W_NAMESPACE (NAMESPACE);

CREATE SEQUENCE  SEQ_W_LIT_DOUBLE_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_LIT_FLOAT_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_LIT_LONG_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_NAMESPACE_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_OBJ_LIT_ANY_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_OBJ_LIT_DATE_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_OBJ_LIT_DATETIME_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_OBJ_LIT_STRING_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_STATEMENT_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_URI_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

  CREATE TABLE @SCHEMA@.W_LOCALE
  (    ID NUMBER(*,0),
       LOCALE VARCHAR2(8)
  ) ;
  
  ALTER TABLE @SCHEMA@.W_LOCALE ADD PRIMARY KEY (ID) ENABLE;

  ALTER TABLE @SCHEMA@.W_LOCALE ADD CONSTRAINT UNIQUE_LOCALE UNIQUE (LOCALE);
  
  INSERT INTO @SCHEMA@.W_LOCALE VALUES (1000, 'root');

  INSERT INTO @SCHEMA@.W_LOCALE VALUES (1001, 'en');

  INSERT INTO @SCHEMA@.W_LOCALE VALUES (1002, 'en-us');
 
  INSERT INTO @SCHEMA@.W_LOCALE VALUES (1003, 'en-uk');
  
  INSERT INTO @SCHEMA@.W_LOCALE VALUES (1004, 'en-gb');

  INSERT INTO @SCHEMA@.W_LOCALE VALUES (1032, 'cs');

  INSERT INTO @SCHEMA@.w_locale VALUES (1064, 'es');

  INSERT INTO @SCHEMA@.w_locale VALUES (1096, 'de');

  INSERT INTO @SCHEMA@.w_locale VALUES (1128, 'de-de');

  INSERT INTO @SCHEMA@.w_locale VALUES (1129, 'fr');

  INSERT INTO @SCHEMA@.w_locale VALUES (1160, 'fr-ca-sk');

  INSERT INTO @SCHEMA@.w_locale VALUES (1161, 'hu');

  INSERT INTO @SCHEMA@.w_locale VALUES (1192, 'it');

  INSERT INTO @SCHEMA@.w_locale VALUES (1224, 'ja');

  INSERT INTO @SCHEMA@.w_locale VALUES (1256, 'ko');

  INSERT INTO @SCHEMA@.w_locale VALUES (1288, 'pl');

  INSERT INTO @SCHEMA@.w_locale VALUES (1320, 'pt-br');

  INSERT INTO @SCHEMA@.w_locale VALUES (1352, 'ru');

  INSERT INTO @SCHEMA@.w_locale VALUES (1384, 'zh');

  INSERT INTO @SCHEMA@.w_locale VALUES (1416, 'zh-tw');

  INSERT INTO @SCHEMA@.w_locale VALUES (1448, 'el');



CREATE TABLE @SCHEMA@.w_subj_pred_index (
    subj_id NUMBER(*,0) NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    predicate_map RAW(1024),
    version_from NUMBER(*,0) NOT NULL,
    version_to NUMBER(*,0) NOT NULL,
    partition_id NUMBER(*,0) NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (subj_id, version_from, version_to, partition_id)
);

CREATE TABLE @SCHEMA@.w_subj_obj_index (
    subj_id NUMBER(*,0) NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    object_map RAW(1024),
    obj_typ_cd NUMBER(*,0) NOT NULL,
    version_from NUMBER(*,0) NOT NULL,
    version_to NUMBER(*,0) NOT NULL,
    partition_id NUMBER(*,0) NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (subj_id, obj_typ_cd, version_from, version_to, partition_id)
);

CREATE TABLE @SCHEMA@.w_pred_subj_index (
    pred_id NUMBER(*,0) NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    subject_map RAW(1024),
    version_from NUMBER(*,0) NOT NULL,
    version_to NUMBER(*,0) NOT NULL,
    partition_id NUMBER(*,0) NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (pred_id, version_from, version_to, partition_id)
);

CREATE TABLE @SCHEMA@.w_pred_obj_index (
    pred_id NUMBER(*,0) NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    object_map RAW(1024),
    obj_typ_cd NUMBER(*,0) NOT NULL,
    version_from NUMBER(*,0) NOT NULL,
    version_to NUMBER(*,0) NOT NULL,
    partition_id NUMBER(*,0) NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (pred_id, obj_typ_cd, version_from, version_to, partition_id)
);

CREATE TABLE @SCHEMA@.w_obj_subj_index (
    obj_id NUMBER(*,0) NOT NULL,
    obj_typ_cd NUMBER(*,0) NOT NULL,
    subject_map RAW(1024),
    version_from NUMBER(*,0) NOT NULL,
    version_to NUMBER(*,0) NOT NULL,
    partition_id NUMBER(*,0) NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (obj_id, obj_typ_cd, version_from, version_to, partition_id)
);

CREATE TABLE @SCHEMA@.w_obj_pred_index (
    obj_id NUMBER(*,0) NOT NULL,
    obj_typ_cd NUMBER(*,0) NOT NULL,
    predicate_map RAW(1024),
    version_from NUMBER(*,0) NOT NULL,
    version_to NUMBER(*,0) NOT NULL,
    partition_id NUMBER(*,0) NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (obj_id, obj_typ_cd, version_from, version_to, partition_id)
);




  CREATE TABLE @SCHEMA@.W_DBVERSION  
  (   SUBSYSTEM VARCHAR2(8) NOT NULL ENABLE, 
      CUR_VERSION NUMBER(*,0) NOT NULL ENABLE   
  ) ;
  ALTER TABLE @SCHEMA@.W_DBVERSION ADD PRIMARY KEY (SUBSYSTEM) ENABLE;


-- *******************************************
-- Mediation
-- *******************************************

create TABLE @SCHEMA@.mediation_tickets (
    targetTicketID varchar(255) not null, 
    ticketEntry long raw, 
    version varchar(255) not null, 
    primary key (targetTicketID));

-- *******************************************
-- RelationshipService
-- *******************************************

CREATE TABLE @SCHEMA@.RELN_METADATA_T(RELATIONSHIP_NAME VARCHAR2(255) NOT NULL, VERSION VARCHAR2(10) NOT NULL);
CREATE UNIQUE INDEX @SCHEMA@.RMT_RELN_NAME_I ON @SCHEMA@.RELN_METADATA_T (RELATIONSHIP_NAME);


CREATE TABLE @SCHEMA@.RELN_VIEW_META_T ( VIEW_NAME VARCHAR(255) NOT NULL,
                RELATIONSHIP_NAME VARCHAR(255) NOT NULL,
                ROLE_NAME VARCHAR(255) NOT NULL,
                VERSION VARCHAR(10) NOT NULL
                            );                                      
CREATE UNIQUE INDEX @SCHEMA@.RELN_VIEW_I ON @SCHEMA@.RELN_VIEW_META_T (RELATIONSHIP_NAME, ROLE_NAME);
